@@ -8,6 +8,7 @@ from django.http import HttpResponse
 from django.utils.simplejson import dumps
 from django.template import Template, loader, RequestContext, Context
 
+from django_helpers.templatetags.static_manger import add_css_file, add_js_file, add_jquery
 
 __author__ = "ajumell"
 
@@ -38,15 +39,15 @@ class DataTableClientRenderedColoum(DataTableColoum):
 
 class DataTableTemplateColoum(DataTableColoum):
     """
-    A Data table coloum which will return a rendered
-    a template insted of a database field.
+    A Data table column which will return a rendered
+    a template instead of a database field.
     """
 
     def __init__(self, field, title, searchable, sortable, template,
                  load_template=True, width=None, value_name='value'):
         """
         @param field: The name of the field to be passed to the template.
-        @param title: Title of the coloum which will be displayed in the table header.
+        @param title: Title of the column which will be displayed in the table header.
         @param searchable: jQuery data table option searchable
         @param sortable: jQuery data table option sortable
         @param template: Template to be rendered as the return value.
@@ -55,7 +56,7 @@ class DataTableTemplateColoum(DataTableColoum):
         load_template parameter as True.
         @param load_template: If this parameter is true the template will
         be loaded.
-        @param width: Width of the coloum
+        @param width: Width of the column
         @param value_name: name of the variable that has to be passed to the template.
         Its default value is "value"
         """
@@ -93,19 +94,36 @@ class DataTable(object):
     display_length = 10
     ajax_source = ''
     loading_message = 'Please wait while data is loading'
+    ui_themes = False
+
+    info_empty = None
+    info_loading = None
+    info_processing = None
 
     dom = '<f>t<plir>'
     template = 'data_tables/table.html'
 
+    def __init__(self):
+        add_css_file('css/table.css')
+        add_css_file('css/ui.css')
+        add_jquery()
+        add_js_file('js/jquery.dataTables.js')
+
     def __unicode__(self):
         template = loader.get_template(self.template)
         context = Context({
             'display_length': self.display_length,
             'dom': self.dom,
             'ajax_source': reverse(self.table_id),
-            'coloums': self.coloums,
+            'columns': self.coloums,
             "table_id": self.table_id,
-            'loading_message': self.loading_message
+            "ui_themes": self.ui_themes,
+            'width': self.width,
+            'loading_message': self.loading_message,
+
+            'info_loading': self.info_loading,
+            'info_processing': self.info_processing,
+            'info_empty': self.info_empty
         })
         return template.render(context)
 
@@ -113,7 +131,7 @@ class DataTable(object):
         GET = request.GET
         gt = GET.get
 
-        coloums = self.coloums
+        columns = self.coloums
         query = self.query.filter()
         extra_params = self.url_search_parameters
         if extra_params is not None:
@@ -133,25 +151,35 @@ class DataTable(object):
         need_related = False
 
         fields, sortings, search, i = [], [], None, -1
-        for coloum in coloums:
-            fields.append(coloum.field)
+        for column in columns:
+            fields.append(column.field)
             i += 1
-            need_related = need_related or coloum.need_related()
+            need_related = need_related or column.need_related()
 
-            if coloum.sortable:
-                field = coloum.field
-                if gt("sSortDir_%d" % i) == "desc":
-                    field = "-" + field
-                sortings.append(field)
-
-            if coloum.searchable and search_term != "":
-                field = coloum.field + "__contains"
+            if column.searchable and search_term != "":
+                field = column.field + "__contains"
                 kwargs = {field: search_term}
                 if search is None:
                     search = Q(**kwargs)
                 else:
                     search = search | Q(**kwargs)
 
+        # Sorting
+        total_sort_columns = gt('iSortingCols')
+        total_sort_columns = int(total_sort_columns)
+        while total_sort_columns:
+            total_sort_columns -= 1
+            column_number = int(gt('iSortCol_%d' % total_sort_columns))
+            sort_order = gt('sSortDir_%d' % total_sort_columns)
+            column = columns[column_number]
+            if column.sortable:
+                field = column.field
+                print sort_order
+                if sort_order == 'desc':
+                    field = '-' + field
+                sortings.append(field)
+
+
         fields = tuple(fields)
         if need_related:
             query = query.select_related()
@@ -166,8 +194,8 @@ class DataTable(object):
 
         for record in query:
             data = []
-            for coloum in coloums:
-                data.append(coloum.get_html(request, record))
+            for column in columns:
+                data.append(column.get_html(request, record))
             datas.append(data)
 
         result = {
@@ -175,7 +203,7 @@ class DataTable(object):
             "sEcho": echo,
             "iTotalRecords": total_length,
             "iTotalDisplayRecords": current_length,
-            }
+        }
         return HttpResponse(dumps(result))
 
 
@@ -201,11 +229,11 @@ def register(data_table):
     if not issubclass(data_table, DataTable):
         raise Exception("A Sub class of DataTable is required.")
 
-    if not hasattr(data_table, 'table_id'):
+    name = getattr(data_table, 'table_id', None)
+    if not name:
         name = str(time.time())
         name = name.replace('.', '')
-    else:
-        name = getattr(data_table, 'table_id')
+
 
     if not name.startswith(url_prefix):
         name = url_prefix + name
