@@ -1,4 +1,5 @@
 from django import template
+register = template.Library()
 
 class LogNode(template.Node):
     def __init__(self, obj):
@@ -9,8 +10,8 @@ class LogNode(template.Node):
         print obj
         return ''
 
-
-def do_log(parser, token):
+@register.tag
+def log(parser, token):
     bits = token.contents.split()
     if len(bits) < 2:
         raise template.TemplateSyntaxError("'%s' tag at least takes one arguments" % bits[0])
@@ -29,14 +30,10 @@ class DIRNode(template.Node):
         return ''
 
 
-def do_dir(parser, token):
+@register.tag
+def dir(parser, token):
     bits = token.contents.split()
     if len(bits) < 2:
         raise template.TemplateSyntaxError("'%s' tag at least takes one arguments" % bits[0])
     value = parser.compile_filter(bits[1])
     return DIRNode(value)
-
-
-register = template.Library()
-register.tag('log', do_log)
-register.tag('dir', do_dir)
\ No newline at end of file
